<?php

class PayshopTwoStepPayment
{
    /**
     * @var PayshopPaymentConfirmation
     */
    private $payshopPaymentConfirmation;

    /**
     * Class constructor
     */
    public function __construct() {
        $this->payshopPaymentConfirmation = new PayshopPaymentConfirmation();
        add_action('wp_ajax_payshop_two_step_payment_confirm', [$this, 'confirm']);
    }

    /**
     * Confirm the efective value of the order to the payment provider
     *
     * @return mixed
     */
    public function confirm()
    {
        if (!wp_verify_nonce($_POST['nonce'], 'payshop_two_step_payment_confirm')) {
            wp_send_json_error();
            wp_die();
        }

        try {
            $effectiveValue = $_POST['effective_value'] ? $_POST['effective_value'] : null;

            if($effectiveValue == null || $effectiveValue == '' || !is_numeric($effectiveValue)) {
                throw new Exception(__('Effective value is invalid', 'payshop'));
            }

            $order = wc_get_order($_POST['order_id']);
            if ($effectiveValue > $order->get_total()) {
                throw new Exception(__('Effective value must be less than order value', 'payshop'));
            }

            $this->payshopPaymentConfirmation->execute($order, $effectiveValue);

            return wp_send_json_success([
                'message' => __('Payment confirmed successfully', 'payshop'),
            ]);
        } catch (\Exception $e) {
            return wp_send_json_error([
               'message' => $e->getMessage(),
            ]);
        }
    }
}