<?php

class PayshopProcessWebhook
{
    /**
     * @var PayshopProcessEvent
     */
    private $payshopProcessEvent;

    /**
     * Class constructor
     */
    public function __construct() {
        add_action('woocommerce_api_payshop_process_webhook', [$this, 'execute']);

        $this->payshopProcessEvent = new PayshopProcessEvent();
    }

    /**
     * Process webhook request sent by the gateway
     *
     * @return void
     */
    public function execute()
    {
        try {
            $json = file_get_contents('php://input');
            $data = json_decode($json, true);

            PayshopEvent::checkEventSignature(
                $data,
                PayshopClientFactory::getSignature()
            );

            if ($this->unprocessablePaymentOrderStatuses($data['order']['status'])) {
                return;
            }

            $this->payshopProcessEvent->execute($data['order']);
        } catch (\Throwable $e) {
            PayshopLog::generate($e->getMessage(), PayshopLog::LOG_SEVERITY_ERROR);

            status_header(500);
            wp_send_json_error(array('message' => $e->getMessage()));
        }

        exit;
    }

    /**
     * Check if the status is unprocessable
     *
     * @param string $orderPaymentStatus
     * @return bool
     */
    private function unprocessablePaymentOrderStatuses($orderPaymentStatus)
    {
        return in_array($orderPaymentStatus, [
            'CREATED',
            'PARTIALLY_REFUNDED',
            'PARTIALLY_CONFIRMED',
            'REFUNDED',
            'PENDING_PROCESSOR_RESPONSE',
            'PENDING_3DS_RESPONSE',
            'PENDING_CARD',
            'USER_CANCELLED',
            'REDIRECTED_TO_3DS',
            'AUTHENTICATION_REQUIRED',
            'PENDING_PAYMENT'
        ]);
    }

}
