<?php

/**
 * Start admin resources
 */
class PayshopAdminBootstrap 
{
    /**
     * Class constructor
     */
    public function execute() {
        if (!is_admin()) {
            return;
        }

        $this->loadFiles();
        $this->loadControllers();
        $this->loadHooks();
    }

    /**
     * Load admin files
     * 
     * @return void
     */
    private function loadFiles() {
        require_once PAYSHOP_PLUGIN_DIR . '/includes/module/alerts/PayshopAbstractAlert.php';
        require_once PAYSHOP_PLUGIN_DIR . '/includes/module/alerts/PayshopRequirementsAlert.php';
        require_once PAYSHOP_PLUGIN_DIR . '/includes/module/alerts/PayshopWoocommerceAlert.php';
        require_once PAYSHOP_PLUGIN_DIR . '/includes/module/alerts/PayshopCredentialsAlert.php';
        require_once PAYSHOP_PLUGIN_DIR . '/includes/module/alerts/PayshopUpdateAlert.php';
        require_once PAYSHOP_PLUGIN_DIR . '/controllers/admin/PayshopUpdateAlertClose.php';

        require_once PAYSHOP_PLUGIN_DIR . '/controllers/admin/PayshopTwoStepPayment.php';

        require_once PAYSHOP_PLUGIN_DIR . '/includes/module/settings/PayshopCredentialsSettings.php';
        require_once PAYSHOP_PLUGIN_DIR . '/includes/module/settings/PayshopPaymentServiceUUID.php';
        require_once PAYSHOP_PLUGIN_DIR . '/includes/module/settings/PayshopPluginListLinks.php';

        require_once PAYSHOP_PLUGIN_DIR . '/includes/module/actions/PayshopPaymentConfirmation.php';
        require_once PAYSHOP_PLUGIN_DIR . '/includes/module/metaboxes/PayshopConfirmPayment.php';
        require_once PAYSHOP_PLUGIN_DIR . '/includes/module/metaboxes/PayshopOrderInformations.php';
    }

    /**
     * Load admin controllers
     * 
     * @return void
     */
    private function loadControllers() {
        new PayshopUpdateAlertClose();
        new PayshopTwoStepPayment();
    }

    /**
     * Load admin the hooks
     * 
     * @return void
     */
    private function loadHooks()
    {
        (new PayshopRequirementsAlert())->execute();
        (new PayshopWoocommerceAlert())->execute();
        (new PayshopCredentialsSettings())->execute();
        (new PayshopPluginListLinks())->execute();
        (new PayshopCredentialsAlert())->execute(); 
        (new PayshopUpdateAlert())->execute();
        (new PayshopConfirmPayment())->execute();
        (new PayshopOrderInformations())->execute();
    }
}