<?php

/**
 * Start the plugin
 */
class PayshopBootstrap 
{
    /**
     * Class constructor
     */
    public function execute() {
        require_once PAYSHOP_PLUGIN_DIR . '/includes/helpers/PayshopLog.php';

        $this->translate();
        $this->loadSDK();
        $this->boostrapAdmin();
        
        if (!class_exists('WC_Payment_Gateway')) {
            return;
        }
        
        $this->loadFiles();
        $this->loadControllers();
        $this->loadHooks();
    }

    /**
     * Load text domain for translation
     * 
     * @return void
     */
    private function translate()
    {
        require_once PAYSHOP_PLUGIN_DIR . '/translations/PayshopLoadTextDomain.php';
        (new PayshopLoadTextDomain())->execute();
    }

    /**
     * Load payshop sdk
     * 
     * @return void
     */
    private function loadSDK()
    {
        require_once PAYSHOP_PLUGIN_DIR . '/includes/sdk/PayshopClientFactory.php';
    }

    /**
     * Bootstrap admin resources
     * 
     * @return void
     */
    private function boostrapAdmin() {
        require_once PAYSHOP_PLUGIN_DIR . '/includes/PayshopAdminBootstrap.php';

        (new PayshopAdminBootstrap())->execute();
    }

    /**
     * Load files
     * 
     * @return void
     */
    private function loadFiles() {
        require_once PAYSHOP_PLUGIN_DIR . '/includes/helpers/PayshopCommons.php';

        require_once PAYSHOP_PLUGIN_DIR . '/includes/sdk/PayshopEvent.php';
        require_once PAYSHOP_PLUGIN_DIR . '/includes/module/events/PayshopProcessEvent.php';

        require_once PAYSHOP_PLUGIN_DIR . '/includes/module/actions/PayshopCreatePaymentOrder.php';
        require_once PAYSHOP_PLUGIN_DIR . '/includes/module/actions/PayshopUpdateOrder.php';

        require_once PAYSHOP_PLUGIN_DIR . '/includes/module/payments/PayshopPaymentMethods.php';
        require_once PAYSHOP_PLUGIN_DIR . '/includes/module/payments/PayshopCard.php';
        require_once PAYSHOP_PLUGIN_DIR . '/includes/module/payments/PayshopMBWay.php';
        require_once PAYSHOP_PLUGIN_DIR . '/includes/module/payments/PayshopReference.php';
        require_once PAYSHOP_PLUGIN_DIR . '/includes/module/payments/PayshopMultibanco.php';

        require_once PAYSHOP_PLUGIN_DIR . '/includes/module/payments/blocks/PayshopPaymentBlocks.php';

        require_once PAYSHOP_PLUGIN_DIR . '/includes/module/dialogs/PayshopReferencesDialog.php';

        require_once PAYSHOP_PLUGIN_DIR . '/includes/module/loaders/PayshopCSS.php';
        require_once PAYSHOP_PLUGIN_DIR . '/includes/module/PayshopAddHeaders.php';

        require_once PAYSHOP_PLUGIN_DIR . '/controllers/front/PayshopProcessWebhook.php';
        require_once PAYSHOP_PLUGIN_DIR . '/controllers/front/PayshopProcessFailedRedirect.php';
    }

    /**
     * Load controllers
     * 
     * @return void
     */
    private function loadControllers()
    {
        new PayshopProcessWebhook();
        new PayshopProcessFailedRedirect();
    }

    /**
     * Load hooks
     * 
     * @return void
     */
    private function loadHooks()
    {
        new PayshopCSS();
        new PayshopPaymentMethods();
        new PayshopPaymentBlocks();
        new PayshopAddHeaders();
        
        (new PayshopReferencesDialog())->execute();
    }
}