<?php

class PayshopCommons
{
    /**
     * Check Payshop response
     *
     * @param array $response
     * @return bool
     * @throws Exception
     */
    public static function checkResponse($response)
    {
        if ($response['status'] == 200) {
            return true;
        }

        if ($response['status'] == 401 || $response['status'] == 403) {
            $message = __('Invalid API credentials. Check your credentials on the module settings.', 'payshop');

            PayshopLog::generate($message, 'error');
            throw new Exception($message);
        }

        if ($response['status'] == 400) {
            $message = __('Invalid gateway settings. Check the service UUID on the payment settings.', 'payshop');

            PayshopLog::generate($message, 'error');
            throw new Exception($message);
        }

        throw new Exception(__("We couldn't connect to the payment gateway.", 'payshop'));
    }

    /**
     * Get date limit to confirm payment
     *
     * @param WC_Order $order
     * @return string
     */
    public static function getDateLimitToConfirmPayment($order)
    {
        $createOrderDate = $order->get_date_created();

        $limiteToConfirmPayment = new DateTime($createOrderDate->format('Y-m-d H:i'));
        
        $daystoConfirmPayment = 'P7D';
        $limiteToConfirmPayment->add(new DateInterval($daystoConfirmPayment));

        return $limiteToConfirmPayment;
    }

    /**
     * Get payment service UUID from the configuration
     *
     * @param WC_Order $order
     * @param array $references
     * @return void
     */
    public static function getPaymentServiceUUID($paymentId)
    {
        return get_option("{$paymentId}_service_uuid");
    }
}