<?php

class PayshopPaymentConfirmation
{
    /**
     * @var PayshopClient
     */
    private $payshopSDK;

    /**
     * Class constructor
     */
    public function __construct()
    {
        $this->payshopSDK = PayshopClientFactory::getInstance();
    }

    /**
     * Confirm payment in two steps on Payshop
     * 
     * @param WC_Order $order
     * @param float $effectiveValue
     * @return bool
     * 
     * @throws Exception
     */
    public function execute($order, $effectiveValue)
    {
            $response = $this->payshopSDK->paymentConfirmation([
                'order_uuid' => $order->get_meta('_payshop_payment_order_uuid'),
                'effective_value' => $effectiveValue * 100,
            ]);

            $this->validateResponseStatus($response);
            $this->validatePaymentSuccess($order, $response);

            $this->updateOrder($order, $response, $effectiveValue);

            return true;
    }

    /**
     * Validate response status
     * 
     * @param array $response
     * @return bool
     * 
     * @throws Exception
     */
    private function validateResponseStatus($response)
    {
        $message = __('Error on send confirmation payment to Payshop. Please, try again', 'payshop');

        if ($response['status'] != 200) {
            throw new Exception($message);
        }

        return true;
    }

    /**
     * Validate if payment was successful confirmated
     * 
     * @param WC_Order $order
     * @param array $response
     * @return bool
     * 
     * @throws Exception
     */
    private function validatePaymentSuccess($order, $response)
    {
        $message = __('Payment confirmation not accepted from Payshop', 'payshop');

        $successful = $response['response']['order']['status'] == 'SUCCESS';
        $paid = $response['response']['order']['paid'];

        if (!$successful || !$paid) {
            throw new Exception($message);
        }

        return true;
    }

    /**
     * Update woocommerce order
     * 
     * @param WC_Order $order
     * @param array $response
     * @param float $effectiveValue
     * @return void
     */
    private function updateOrder($order, $response, $effectiveValue)
    {
        $order->update_meta_data('_payshop_payment_id', 'asd', true);
        $order->update_meta_data('_payshop_effective_value', $effectiveValue, true);
        
        $order->save();
    }
}