<?php

class PayshopCredentialsAlert extends PayshopAbstractAlert
{
    /**
     * Check if credentials are set
     * 
     * @return void
     */
    public function execute()
    {
        $this->checkProdutionCredencials();

        $this->checkSandboxCredencials();
    }

    /**
     * Check if production credentials are set
     * 
     * @return void
     */
    private function checkProdutionCredencials()
    {
        if (get_option('payshop_environment') == 'sandbox') {
            return;
        }

        if (!get_option('payshop_api_key') || !get_option('payshop_signature') || !get_option('payshop_client_uuid')) {
            $type    = 'error';
            $message = __('Payshop Error: Check prodution credentials on payshop settings.', 'payshop');

            $this->show($type, $message);
        }
    }

    /**
     * Check if sandbox credentials are set
     * 
     * @return void
     */
    private function checkSandboxCredencials()
    {
        if (get_option('payshop_environment') == 'production') {
            return;
        }

        if (!get_option('payshop_sandbox_api_key') || !get_option('payshop_sandbox_signature') || !get_option('payshop_sandbox_client_uuid')) {
            $type    = 'error';
            $message = __('Payshop Error: Check Sandbox credentials on payshop settings.', 'payshop');

            $this->show($type, $message);
        }
    }
}