<?php

class PayshopWoocommerceAlert extends PayshopAbstractAlert
{
    /**
     * Check if WooCommerce is installed and active
     * 
     * @return void
     */
    public function execute()
    {
        if (class_exists('WC_Payment_Gateway')) {
            return;
        }

        $this->activeWoocommerce();

        $this->InstallWoocommerce();
    }

    /**
     * Check if the PHP version is correct
     * 
     * @return void
     */
    private function activeWoocommerce()
    {
        if ($this->isWoocommerceInstaled()) {
            $type    = 'error';
            $message = __('Payshop Error: Please active Woocommerce', 'payshop');

            $this->show($type, $message);
        }
    }

    /**
     * Check if the CURL extension is installed
     * 
     * @return void
     */
    private function InstallWoocommerce()
    {
        if (!$this->isWoocommerceInstaled()) {
            $type    = 'error';
            $message = __('Payshop Error: Please install Woocommerce.', 'payshop');

            $this->show($type, $message);
        }
    }

    /**
     * Check if the Woocommerce is installed
     * 
     * @return void
     */
    private function isWoocommerceInstaled()
    {
        if (!function_exists('get_plugins')) {
            require_once ABSPATH . 'wp-admin/includes/plugin.php';
        }
        
        $allPlugins  = get_plugins();

        return !empty($allPlugins['woocommerce/woocommerce.php']);
    }
}