<?php

require_once 'PayshopPaymentRefused.php';
require_once 'PayshopPaymentSuccess.php';

 class PayshopProcessEvent
 {
    /**
     * @var PayshopClient
     */
    private $payshopSDK;

    /**
     * @var PayshopPaymentSuccess
     */
    private $payshopPaymentSuccess;

    /**
     * @var PayshopPaymentRefused
     */
    private $payshopPaymentRefused;

    /**
     * Class constructor
     */
    public function __construct()
    {
        $this->payshopSDK = PayshopClientFactory::getInstance();
        $this->payshopPaymentSuccess = new PayshopPaymentSuccess();
        $this->payshopPaymentRefused = new PayshopPaymentRefused();
    }

    /**
     * Process webhook events
     *
     * @param array $eventBasicInformation
     * @return void
     */
    public function execute($paymentOrder)
    {
        $order = $this->getOrderByPaymentOrderUUID($paymentOrder['uuid']);
        $this->addMetadataAppName($paymentOrder);

        $isPaymentInTwoStep = $order->get_meta('_payshop_payment_in_two_steps') == 'yes';

        if ($isPaymentInTwoStep) {
            if ($paymentOrder['status'] == 'PENDING_CONFIRMATION' && $paymentOrder['transactions'][0]['status'] == 'SUCCESS') {
                return $this->payshopPaymentSuccess->process($order);

            }
        }

        if ($paymentOrder['status'] == 'SUCCESS' && $paymentOrder['paid'] == true) {
            return $this->payshopPaymentSuccess->process($order);
        }

        return $this->payshopPaymentRefused->process($order);
    }


    /**
     * Get order woocommerce by payment order uuid
     *
     * @param string $paymentOrderUUID
     * @return WC_Order
     */
    private function getOrderByPaymentOrderUUID($paymentOrderUUID)
    {
        //get order by meta on woocommerce
        $order = wc_get_orders([
            'post_status' => 'any',
            'meta_key' => '_payshop_payment_order_uuid',
            'meta_value' => $paymentOrderUUID,
            'meta_compare'  => '=', 
            'return'        => 'ids',
            'posts_per_page' => 1
        ]);

        $order = wc_get_order($order[0]);

        return $order;
    }

    /**
     * Add metadata app name to instruction
     * 
     * @param  array  $instruction
     * @return void
     */
    private function addMetadataAppName(array $paymentOrder): void
    {
        $transactions = $paymentOrder['transactions'] ?? [];

        if (!$transactions) {
            return;
        }

        $transaction = $transactions[count($transactions) - 1];

        if (!isset($transaction['uuid'])) {
            return;
        }
        
        $this->payshopSDK->createTransationMetadata(
            $transaction['uuid'],
            [
                'metadata' => [
                    'source_application' => 'wooCommerce_plugin'
                ]
            ]
        );
    }
 }