<?php

use Automattic\WooCommerce\Internal\DataStores\Orders\CustomOrdersTableController;

class PayshopConfirmPayment
{
    /**
     * Create payment confirmation metabox
     * 
     * @return void
     */
    public function execute()
    {
        add_action('add_meta_boxes', [$this, 'addMetaBox']);
    }
    
    /**
     * Add metabox
     * 
     * @return void
     */
    public function addMetaBox()
    {
        if (!$this->getOrder()) {
            return;
        }

        if ($this->isNotPayshopCard() || $this->isNotPaymentInTwoSteps()) {
            return;
        }

        if ($this->orderIsNotPaid() || $this->paymentIsCompleted()) {
            return;
        }
        
        if ($this->passedDateLimitToConfirmPayment()) {
            return;
        }

        $screen = class_exists( '\Automattic\WooCommerce\Internal\DataStores\Orders\CustomOrdersTableController' ) && wc_get_container()->get( CustomOrdersTableController::class )->custom_orders_table_usage_is_enabled()
        ? wc_get_page_screen_id( 'shop-order' )
        : 'shop_order';

        add_meta_box(
            'payshop-confirm-payment',
            __('Confirm Payment', 'payshop'),
            [$this, 'renderMetaBox'],
            $screen,
            'side',
            'core'
        );
    }

    /**
     * Render metabox
     * 
     * @return void
     */
    public function renderMetaBox()
    {
        // Used on template
        $order = $this->getOrder();

        require_once PAYSHOP_PLUGIN_DIR . '/templates/views/admin/confirm-payment.php';
    }
    
    /**
     * Get order
     * 
     * @return WC_Order
     */
    private function getOrder()
    {
        $postId = $_GET['id'];

        if (!$postId) {
            return;
        }

        $order = wc_get_order($postId);
        if (!$order) {
            return;
        }

        return $order;
    }

    /**
     * Check date limit to confirm payment
     * 
     * @return bool
     */
    private function passedDateLimitToConfirmPayment()
    {
        $order = $this->getOrder();

        $dateLimitToConfirmPayment = PayshopCommons::getDateLimitToConfirmPayment($order);
        $currentDate = new DateTime();

        return $currentDate > $dateLimitToConfirmPayment;
    }

    /**
     * Check if is not payshop card
     * 
     * @return bool
     */
    private function isNotPayshopCard()
    {
        $order = $this->getOrder();

        $paymentMethod = $order->get_payment_method();

        return $paymentMethod !== 'payshop_card';
    }

    /**
     * Check if is not payment in two steps
     * 
     * @return bool
     */
    private function isNotPaymentInTwoSteps()
    {
        $order = $this->getOrder();

        $paymentInTwoSteps = $order->get_meta('_payshop_payment_in_two_steps');
        
        return $paymentInTwoSteps !== 'yes';
    }

    /**
     * Check if order is not paid
     * 
     * @return bool
     */
    private function orderIsNotPaid()
    {
        $order = $this->getOrder();

        return $order->get_status() !== 'processing' && $order->get_status() !== 'completed';
    }

    /**
     * Check if paymente is confirmed
     * 
     * @return bool
     */
    private function paymentIsCompleted()
    {
        $order = $this->getOrder();

        $payshopEffectiveValue = $order->get_meta('_payshop_effective_value');

        return !!$payshopEffectiveValue;
    }
}
