<?php

use Automattic\WooCommerce\Blocks\Payments\Integrations\AbstractPaymentMethodType;

class PayshopMBWayBlock extends AbstractPaymentMethodType
{
    /**
     * WC_Payment_Gateway
     */
    private $gateway;

    /**
     * string
     */
    protected $name = 'payshop_mbway';

    /**
    * Initialize the payment method.
    *
    * @return void
    */
    public function initialize() {
        $this->settings = get_option( 'woocommerce_payshop_mbway_settings', [] );
        $this->gateway = new PayshopMBWay();
    }

    /**
    * Check if the payment method is active.
    *
    * @return void
    */
    public function is_active() {
        return $this->gateway->is_available();
    }

    /**
    * Get the payment method script handles.
    *
    * @return array
    */
    public function get_payment_method_script_handles() {
        wp_register_script(
            'payshop-mbway-blocks-integration',
            PAYSHOP_PLUGIN_URL . 'templates/blocks/build/mbway.js',
            [
                'wc-blocks-registry',
                'wc-settings',
                'wp-element',
                'wp-html-entities',
                'wp-i18n',
            ],
            null,
            true
        );
        if( function_exists( 'wp_set_script_translations' ) ) {            
            wp_set_script_translations( 'payshop-mbway-blocks-integration');
            
        }
        return [ 'payshop-mbway-blocks-integration' ];
    }

    /**
     * Define the payment method data.
     *
     * @return array
     */
    public function get_payment_method_data() {
        return [
            'title' => $this->gateway->title,
            'icon' => $this->gateway->icon,
            'description' => __('After click on confirmation button. You will see form to insert your card informations on the next page', 'payshop'),
            'field_description' => __('Phone number', 'payshop'),
            'error_message' => __('Invalid MBWay Phone Number', 'payshop'),
        ];
    }
}
