<?php

use Automattic\WooCommerce\Blocks\Payments\Integrations\AbstractPaymentMethodType;

class PayshopMultibancoBlock extends AbstractPaymentMethodType
{
    /**
     * WC_Payment_Gateway
     */
    private $gateway;

    /**
     * string
     */
    protected $name = 'payshop_multibanco';

    /**
    * Initialize the payment method.
    *
    * @return void
    */
    public function initialize() {
        $this->settings = get_option( 'woocommerce_payshop_multibanco_settings', [] );
        $this->gateway = new PayshopMultibanco();
    }

    /**
    * Check if the payment method is active.
    *
    * @return void
    */
    public function is_active() {
        return $this->gateway->is_available();
    }

    /**
    * Get the payment method script handles.
    *
    * @return array
    */
    public function get_payment_method_script_handles() {
        wp_register_script(
            'payshop-multibanco-blocks-integration',
            PAYSHOP_PLUGIN_URL . 'templates/blocks/build/multibanco-reference.js',
            [
                'wc-blocks-registry',
                'wc-settings',
                'wp-element',
                'wp-html-entities',
                'wp-i18n',
            ],
            null,
            true
        );
        if( function_exists( 'wp_set_script_translations' ) ) {            
            wp_set_script_translations( 'payshop-multibanco-blocks-integration');
            
        }
        return [ 'payshop-multibanco-blocks-integration' ];
    }
    
    /**
     * Define the payment method data.
     *
     * @return array
     */
    public function get_payment_method_data() {
        return [
            'title' => $this->gateway->title,
            'icon' => $this->gateway->icon,
            'description' => __('After click on confirmation button. You will see reference on the next page', 'payshop'),
        ];
    }
}
