<?php

use Automattic\WooCommerce\Utilities\FeaturesUtil;
use Automattic\WooCommerce\Blocks\Payments\Integrations\AbstractPaymentMethodType;

class PayshopPaymentBlocks
{
    /**
     * class constructor
     */
    public function __construct()
    {
        add_action('before_woocommerce_init', [$this, 'declareBlocksCompatibility']);
        add_action('woocommerce_blocks_loaded', [$this, 'addPaymentBlocks']);
    }

    /**
     * Register payment methods
     * 
     * @return void
     */
    public function declareBlocksCompatibility()
    {
        if (class_exists(FeaturesUtil::class)) {
            $pluginFile = PAYSHOP_PLUGIN_DIR . '/payshop.php';
            FeaturesUtil::declare_compatibility('cart_checkout_blocks',  $pluginFile, true);
        }
    }

    /**
     * Register payment methods
     * 
     * @return void
     */
    function addPaymentBlocks() {
        if (! class_exists(AbstractPaymentMethodType::class)) {
            return;
        }
    
        require_once PAYSHOP_PLUGIN_DIR . '/includes/module/payments/blocks/PayshopCardBlock.php';
        require_once PAYSHOP_PLUGIN_DIR . '/includes/module/payments/blocks/PayshopReferenceBlock.php';
        require_once PAYSHOP_PLUGIN_DIR . '/includes/module/payments/blocks/PayshopMultibancoBlock.php';
        require_once PAYSHOP_PLUGIN_DIR . '/includes/module/payments/blocks/PayshopMBWayBlock.php';
    
        add_action(
            'woocommerce_blocks_payment_method_type_registration',
            function( Automattic\WooCommerce\Blocks\Payments\PaymentMethodRegistry $payment_method_registry ) {
                $payment_method_registry->register(new PayshopCardBlock);
                $payment_method_registry->register(new PayshopMBWayBlock);
                $payment_method_registry->register(new PayshopReferenceBlock);
                $payment_method_registry->register(new PayshopMultibancoBlock);
            }
        );
    }
}