<?php

class PayshopCredentialsSettings
{
    /**
     * @var PayshopPaymentServiceUUID
     */
    private $PayshopPaymentServiceUUID;

    /**
     * Define payshop credentials settings
     * 
     * @return void
     */
    public function execute()
    {
        $this->PayshopPaymentServiceUUID = new PayshopPaymentServiceUUID();
        add_filter('woocommerce_settings_tabs_array', [$this, 'addSettingsTab'], 50);
        add_action('woocommerce_settings_tabs_payshop', [$this, 'settingsTab']);
        add_action('woocommerce_update_options_payshop', [$this, 'updateSettings']);
    }
    
    /**
     * Add payshop settings tab
     * 
     * @param array $settingsTabs
     * @return array
     */
    public function addSettingsTab($settingsTabs)
    {
        $settingsTabs['payshop'] = __('Payshop', 'payshop');

        return $settingsTabs;
    }

    /**
     * Define fields in Settings tab
     * 
     * @return void
     */
    public function settingsTab()
    {
        woocommerce_admin_fields($this->getSettings());
    }

    /**
     * Save settings fields
     * 
     * @return array
     */
    public function updateSettings()
    {
        woocommerce_update_options($this->getSettings());

        try {
            $this->PayshopPaymentServiceUUID->execute();
        } catch (\Throwable $th) {
            echo "<script>alert('". __('Check the gateway payment credentials', 'payshop'). "');</script>";
        }
    }

    /**
     * Define settings fields
     * 
     * @return array
     */
    private function getSettings()
    {
        return $this->generalSettings() + 
               $this->productionApiSettings() +
               $this->sandboxApiSettings();
    }

    /**
     * Define general settings fields
     * 
     * @return array
     */
    private function generalSettings()
    {
        return [
            'section_general_title' => [
                'name' => __('Payshop Settings', 'payshop'),
                'type' => 'title',
                'desc' => '',
                'id' => 'section_general_title'
            ],
            'payshop_environment' => [
                'name' => __('Environment', 'payshop'),
                'type' => 'select',
                'desc' => __('Select the environment you want to use', 'payshop'),
                'id' => 'payshop_environment',
                'options' => [
                    'sandbox' => __('Sandbox', 'payshop'),
                    'production' => __('Production', 'payshop')
                ]
            ],
            'section_general_end' => [
                'type' => 'sectionend',
                'id' => 'section_general_end'
            ]
        ];
    }

    /**
     * Define production API settings fields
     * 
     * @return array
     */
    private function productionApiSettings()
    {
        return [
            'section_production_title' => [
                'name' => __('Payshop Prodution Credentials', 'payshop'),
                'type' => 'title',
                'desc' => '',
                'id' => 'section_production_title'
            ],
            'payshop_api_key' => [
                'name' => __('API Key', 'payshop'),
                'type' => 'text',
                'desc' => __('Enter your Payshop API Key', 'payshop'),
                'id' => 'payshop_api_key'
            ],
            'payshop_signature' => [
                'name' => __('Signature', 'payshop'),
                'type' => 'text',
                'desc' => __('Enter your Payshop Signature', 'payshop'),
                'id' => 'payshop_signature'
            ],
            'payshop_client_uuid' => [
                'name' => __('Client UUID', 'payshop'),
                'type' => 'text',
                'desc' => __('Enter your Payshop Client UUID', 'payshop'),
                'id' => 'payshop_client_uuid'
            ],
            'section_production_end' => [
                'type' => 'sectionend',
                'id' => 'section_production_end'
            ]
        ];
    }

    /**
     * Define sandbox API settings fields
     * 
     * @return array
     */
    private function sandboxApiSettings()
    {
        return [
            'section_sandbox_title' => [
                'name' => __('Payshop Sandbox (test) Credentials', 'payshop'),
                'type' => 'title',
                'desc' => '',
                'id' => 'section_sandbox_title'
            ],
            'payshop_sandbox_api_key' => [
                'name' => __('API Key', 'payshop'),
                'type' => 'text',
                'desc' => __('Enter your Payshop API Key', 'payshop'),
                'id' => 'payshop_sandbox_api_key'
            ],
            'payshop_sandbox_signature' => [
                'name' => __('Signature', 'payshop'),
                'type' => 'text',
                'desc' => __('Enter your Payshop Signature', 'payshop'),
                'id' => 'payshop_sandbox_signature'
            ],
            'payshop_sandbox_client_uuid' => [
                'name' => __('Client UUID', 'payshop'),
                'type' => 'text',
                'desc' => __('Enter your Payshop Client UUID', 'payshop'),
                'id' => 'payshop_sandbox_client_uuid'
            ],
            'section_sandbox_end' => [
                'type' => 'sectionend',
                'id' => 'section_sandbox_end'
            ]
        ];
    }
}

