<?php

require_once 'PayshopClient.php';

class PayshopClientFactory
{
    public function __construct()
    {
    }

    static $payshopClient = null;

    /**
     * Instanciete the class
     *
     * @return PayshopClient
     */
    public static function getInstance()
    {
        if (null === self::$payshopClient) {
            try {
                self::$payshopClient = new PayshopClient(
                    self::getApiKey(),
                    self::getSignature(),
                    self::isProduction()
                );
                
            } catch (\Exception $e) {
                $message = 'API ' . $e->getMessage();
                
                PayshopLog::generate($message, PayshopLog::LOG_SEVERITY_ERROR);
            }
        }

        return self::$payshopClient;
    }

    /**
     * Check if the module is in production mode
     *
     * @return boolean
     */
    public static function isProduction()
    {
        return get_option('payshop_environment') == 'production';
    }

    /**
     * Get public key based on the environment
     *
     * @return string
     */
    public static function getApiKey()
    {
        if (self::isProduction() == true) {
            return get_option('payshop_api_key');
        }

        return get_option('payshop_sandbox_api_key');
    }

    /**
     * Get secret key based on the environment
     *
     * @return string
     */
    public static function getSignature()
    {
        if (self::isProduction() == true) {
            return get_option('payshop_signature');
        }

        return get_option('payshop_sandbox_signature');
    }

    /**
     * Get client UUID key based on the environment
     *
     * @return string
     */
    public static function getClientUUID()
    {
        if (self::isProduction() == true) {
            return get_option('payshop_client_uuid');
        }

        return get_option('payshop_sandbox_client_uuid');
    }
}